using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using O2S.Barcode4NET;

namespace BarcodeListControls
{
	/// <summary>
	/// Listbox control that displays a barcode for each item.
	/// </summary>
	public class BarcodeListBox : ListBox
	{
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		public BarcodeListBox()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();

			DrawMode = DrawMode.OwnerDrawFixed;
			ItemHeight = 80;
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if( components != null )
					components.Dispose();
			}
			base.Dispose( disposing );
		}

		#region Component Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			components = new System.ComponentModel.Container();
		}
		#endregion

		/// <summary>
		/// 
		/// </summary>
		/// <param name="e"></param>
		protected override void OnDrawItem(DrawItemEventArgs e)
		{
			if( e.Index < Items.Count )
			{
				e.DrawBackground( );

				// Get the row being drawn.
				DataRowView dr = ( DataRowView )Items[e.Index];
				// Get the customer id
				string displayItem = dr[DisplayMember].ToString( );

				// Use a Code 39 barcode for the strings in the list.
				Code39Barcode c39 = new Code39Barcode( displayItem );
				c39.DimensionUnit = XYDimensionUnit.Pixel;
				c39.XDimension = 1;
				c39.YDimension = 50; 
				c39.DataDisplayLocation = BarcodeTextLocation.BelowEmbedded;

				// Get the size of the barcode.
				SizeF barcodeSize = c39.GetSize( e.Graphics.DpiX, e.Graphics.DpiY );

				// Draw the barcode centered in the list.
				c39.Draw( e.Graphics, ( e.Bounds.Left + e.Bounds.Right - barcodeSize.Width )/2, e.Bounds.Top + 3 );

				e.DrawFocusRectangle( );
			}
		}
	}
}
